module SpecJs
  module CLI
    extend self

    def options
      @options ||= {
        :color => true,
        :files => [],
        :pattern => "spec/**/*spec.js",
        :no_envjs => false
      }
    end

    def run
      started = Time.now.to_f

      OptionParser.new do |opts|
        opts.on("-c", "--[no-]color", "Output colored results") do |v|
          options[:color] = v
        end

        opts.on("--no-envjs", "Don't load Env.js and jQuery") do |v|
          options[:no_envjs] = true
        end

        opts.on("-p", "--pattern", "Specify the file searching pattern. Defaults to spec/**/*spec.js") do |v|
          options[:pattern] = v
        end

        opts.on_tail("-h", "--help", "Show this message") do
          puts opts
          exit
        end

        opts.on_tail("-v", "--version", "Show version") do
          puts SpecJs::Version::STRING
          exit
        end

      end.parse!

      retrieve_files!

      Runner.new(options.merge(:started => started)).run
    end

    def retrieve_files!
      path = File.expand_path(ARGV.first || options[:pattern])
      path = File.join(path, "**/*spec.js") if File.directory?(path)
      options[:files] += Dir[path]
    end
  end
end
