require "rake"
require "rake/tasklib"
require "spec_js"

module SpecJs
  class RakeTask < ::Rake::TaskLib
    attr_accessor :name
    attr_accessor :pattern
    attr_accessor :color_enabled
    attr_accessor :env_js

    def initialize(*args)
      @name = args.shift || :"spec:js"
      @pattern = "spec/**/*spec.js"
      @color_enabled = true
      @env_js = true

      yield self if block_given?

      desc("Run JavaScript code examples")
      task name do
        if files_to_run.empty?
          puts "No examples matching #{pattern} could be found"
        else
          Runner.new(options).run
        end
      end
    end

    private
    def options
      {
        :started => Time.now.to_f,
        :color => color_enabled,
        :pattern => pattern,
        :files => files_to_run,
        :no_envjs => !env_js
      }
    end

    def files_to_run
      if ENV["SPEC"]
        FileList[ENV["SPEC"]]
      else
        FileList[pattern].map { |f| File.expand_path(f)}
      end
    end
  end
end
