describe(".toBe", function(){
	specify("one array should be itself", function(){
		items = [1,2,3];
		expect(items).toBe(items);
	});
	
	specify("one array should not be another", function(){
		expect([1]).not.toBe([1]);
	});
	
	should("have alias", function(){
		expect(Spec.Matcher.prototype.to_be).toBeEqualTo(Spec.Matcher.prototype.toBe);
	});
});

describe(".toBeInstanceOf", function(){
	should("be a string", function(){
		expect("dummy").toBeInstanceOf(String);
	});
	
	should("not be a string", function(){
		expect(123).not.toBeInstanceOf(String);
	});
	
	should("be a number", function(){
		expect(1).toBeInstanceOf(Number);
	});
	
	should("not be a number", function(){
		expect("dummy").not.toBeInstanceOf(Number);
	});
	
	should("be an array", function(){
		expect([]).toBeInstanceOf(Array);
	});
	
	should("not be an array", function(){
		expect("dummy").not.toBeInstanceOf(Array);
	});
	
	should("be an object", function(){
		expect({}).toBeInstanceOf(Object);
	});
	
	should("have alias", function(){
		expect(Spec.Matcher.prototype.to_be_instance_of).toBeEqualTo(Spec.Matcher.prototype.toBeInstanceOf);
	});
});

describe(".toBeEqualTo", function(){
	specify("1 should be equal to 1", function(){
		expect(1).toBeEqualTo(1);
	});
	
	specify("0 should not be equal to 1", function(){
		expect(0).not.toBeEqualTo(1);
	});
	
	specify("one object should be equal to another", function(){
		expect({a: 1}).toBeEqualTo({a: 1});
	});
	
	specify("one array should be equal to array", function(){
		expect([[1,2,3]]).toBeEqualTo([[1,2,3]]);
	});
	
	should("have alias", function(){
		expect(Spec.Matcher.prototype.to_be_equal_to).toBeEqualTo(Spec.Matcher.prototype.toBeEqualTo);
	});
});

describe(".toBeNull", function(){
	specify("null should be null", function(){
		expect(null).toBeNull();
	});
	
	specify("1 should not be null", function(){
		expect(1).not.toBeNull();
	});
	
	should("have alias", function(){
		expect(Spec.Matcher.prototype.to_be_null).toBeEqualTo(Spec.Matcher.prototype.toBeNull);
	});
});

describe(".toBeUndefined", function(){
	specify("undefined should be undefined", function(){
		expect(undefined).toBeUndefined();
	});
	
	specify("1 should not be undefined", function(){
		expect(1).not.toBeUndefined();
	});
	
	should("have alias", function(){
		expect(Spec.Matcher.prototype.to_be_undefined).toBeEqualTo(Spec.Matcher.prototype.toBeUndefined);
	});
});

describe(".toBeDefined", function(){
	specify("1 should be defined", function(){
		expect(1).toBeDefined();
	});
	
	specify("undefined should not be defined", function(){
		expect(undefined).not.toBeDefined();
	});
	
	should("have alias", function(){
		expect(Spec.Matcher.prototype.to_be_defined).toBeEqualTo(Spec.Matcher.prototype.toBeDefined);
	});
});

describe(".toThrow", function(){
	should("throw error without message", function(){
		expect(function(){
			throw "Error";
		}).toThrow();
	});
	
	should("throw error with message", function(){
		expect(function(){
			throw "This is just an error";
		}).toThrow("This is just an error");
	});
	
	should("not throw error without message", function(){
		expect(function(){}).not.toThrow();
	});
	
	should("not throw error with different messages", function(){
		expect(function(){ throw "Error"; }).not.toThrow("This is just an error");
	});
	
	should("have alias", function(){
		expect(Spec.Matcher.prototype.to_throw).toBeEqualTo(Spec.Matcher.prototype.toThrow);
	});
});

describe(".toBeEmpty", function(){
	specify("array should be empty", function(){
		expect([]).toBeEmpty();
	});
	
	specify("array should not be empty", function(){
		expect([1]).not.toBeEmpty();
	});
	
	specify("string should be empty", function(){
		expect("").toBeEmpty();
	});
	
	specify("string should not be empty", function(){
		expect("testing").not.toBeEmpty();
	});
	
	should("have alias", function(){
		expect(Spec.Matcher.prototype.to_be_empty).toBeEqualTo(Spec.Matcher.prototype.toBeEmpty);
	});
});

describe(".toMatch", function(){
	should("match at least one letter", function(){
		expect("123abc").toMatch(/[a-z]/);
	});
	
	should("not match a letter", function(){
		expect("123").not.toMatch(/[a-z]/);
	});
	
	should("have alias", function(){
		expect(Spec.Matcher.prototype.to_match).toBeEqualTo(Spec.Matcher.prototype.toMatch);
	});
});

describe(".toBeFalse", function(){
	should("be false", function(){
		expect(false).toBeFalse();
	});
	
	should("not be false", function(){
		expect(true).not.toBeFalse();
	});
	
	should("have alias", function(){
		expect(Spec.Matcher.prototype.to_be_false).toBeEqualTo(Spec.Matcher.prototype.toBeFalse);
	});
});

describe(".toBeTrue", function(){
	should("be true", function(){
		expect(true).toBeTrue();
	});
	
	should("not be true", function(){
		expect(false).not.toBeTrue();
	});
	
	should("have alias", function(){
		expect(Spec.Matcher.prototype.to_be_true).toBeEqualTo(Spec.Matcher.prototype.toBeTrue);
	});
});

describe(".toContain", function(){
	specify("array should contain string", function(){
		expect(["a", "ab", "abc"]).toContain("a");
	});
	
	specify("array should not contain string", function(){
		expect(["a", "ab", "abc"]).not.toContain("b");
	});
	
	specify("string should contain substring", function(){
		expect("some dummy string").toContain("dummy");
	});
	
	specify("string should not contain substring", function(){
		expect("some dummy string").not.toContain("foo");
	});
	
	should("have alias", function(){
		expect(Spec.Matcher.prototype.to_contain).toBeEqualTo(Spec.Matcher.prototype.toContain);
	});
});

describe(".toHaveAttr", function(){
	should("have attribute", function(){
		expect({a: 1}).toHaveAttr("a");
	});
	
	should("not have attribute", function(){
		expect({}).not.toHaveAttr("a");
	});
	
	should("have attribute with value", function(){
		expect({a: 1}).toHaveAttr("a", 1);
	});
	
	should("not have attribute with value", function(){
		expect({}).not.toHaveAttr("a", 2);
	});
	
	should("have alias", function(){
		expect(Spec.Matcher.prototype.to_have_attr).toBeEqualTo(Spec.Matcher.prototype.toHaveAttr);
	});
});

describe(".toHaveLength", function(){
	should("have 3 items", function(){
		expect([1,2,3]).toHaveLength(3);
	});
	
	should("not have 3 items", function(){
		expect([1,2,3]).not.toHaveLength(2);
	});
	
	should("have alias", function(){
		expect(Spec.Matcher.prototype.to_have_length).toBeEqualTo(Spec.Matcher.prototype.toHaveLength);
	});
});

describe(".toBeGreaterThan", function(){
	should("be greater than 1", function(){
		expect(2).toBeGreaterThan(1);
	});
	
	should("not be greater than 1", function(){
		expect(1).not.toBeGreaterThan(1);
	});
	
	should("have alias", function(){
		expect(Spec.Matcher.prototype.to_be_greater_than).toBeEqualTo(Spec.Matcher.prototype.toBeGreaterThan);
	});
});

describe(".toBeLessThan", function(){
	should("be less than 3", function(){
		expect(1).toBeLessThan(3);
	});
	
	should("not be less than 3", function(){
		expect(3).not.toBeLessThan(3);
	});
	
	should("have alias", function(){
		expect(Spec.Matcher.prototype.to_be_less_than).toBeEqualTo(Spec.Matcher.prototype.toBeLessThan);
	});
});

describe(".toBeWithin", function(){
	should("be within 3 and 5", function(){
		expect(3).toBeWithin(3,5);
		expect(4).toBeWithin(3,5);
		expect(5).toBeWithin(3,5);
	});
	
	should("not be within 3 and 5", function(){
		expect(2).not.toBeWithin(3,5);
		expect(6).not.toBeWithin(3,5);
	});
	
	should("have alias", function(){
		expect(Spec.Matcher.prototype.to_be_within).toBeEqualTo(Spec.Matcher.prototype.toBeWithin);
	});
});

describe(".toHaveBeenCalledWith", function(){
	before(function(){
		object = new String("Nice String");
	});
	
	specify("call method with attributes", function(){
		spy(object, "substr");
		object.substr(0, 4);
		expect(object.substr).toHaveBeenCalledWith(0, 4);
	});
	
	specify("don't call method with provided attributes", function(){
		spy(object, "substr");
		object.substr(0, 4);
		expect(object.substr).not.toHaveBeenCalledWith(1, 4);
	});
	
	should("have alias", function(){
		expect(Spec.Matcher.prototype.to_have_been_called_with).toBeEqualTo(Spec.Matcher.prototype.toHaveBeenCalledWith);
	});
});

describe(".toHaveBeenCalled", function(){
	before(function(){
		object = new String("Nice String");
		object.downcase = object.toLowerCase;
	});
	
	specify("call method without attributes", function(){
		spy(object, "downcase");
		object.downcase();
		expect(object.downcase).toHaveBeenCalled();
	});
	
	specify("method should not be called without attributes", function(){
		spy(object, "downcase");
		expect(object.downcase).not.toHaveBeenCalled();
	});
	
	should("have alias", function(){
		expect(Spec.Matcher.prototype.to_have_been_called).toBeEqualTo(Spec.Matcher.prototype.toHaveBeenCalled);
	});
});
