describe("Mocks", function(){
	before(function(){
		object = {};
	});
	
	should("stub as attribute", function(){
		stub(object, "downcase", "some nice string");
		expect(object.downcase).toBeEqualTo("some nice string");
	});
	
	should("stub as pseudo-function", function(){
		stub(object, "downcase()", "some nice string");
		expect(object).toRespondTo("downcase");
		expect(object.downcase()).toBeEqualTo("some nice string");
	});
	
	should("stub as function", function(){
		stub(object, "downcase", function() { return "some nice string"; });
		expect(object).toRespondTo("downcase");
		expect(object.downcase()).toBeEqualTo("some nice string");
	});
	
	should("stub as an existing function", function(){
		stub(object, "toString()", "stubbed");
		expect(object.toString()).toBeEqualTo("stubbed");
	});
	
	should("return original attribute", function(){
		object.name = "John Doe";
		stub(object, "name", "Mary Doe");
		unstub(object);
		expect(object.name).toBeEqualTo("John Doe");
	});
	
	should("unstub all objects", function(){
		object1 = {name: "object1"};
		object2 = {name: "object2"};
		
		stub(object1, "name", "stubbed object1");
		stub(object2, "name", "stubbed object2");
		
		Spec.Mock.unstubAll();
		
		expect(object1.name).toBeEqualTo("object1");
		expect(object2.name).toBeEqualTo("object2");
		
		expect(object1).not.toHaveAttr("stubId");
		expect(object2).not.toHaveAttr("stubId");
		
		expect(Spec.Mock.objects.length).toBeEqualTo(0);
	});
});
