describe("Spy", function(){
	before(function(){
		object = new String("Some Nice String");
		object.downcase = function() {
			return this.toLowerCase();
		};
	});
	
	should("inject method", function(){
		spy(object, "downcase");
		expect(object).toRespondTo("downcase");
	});
	
	should("register messages without arguments", function(){
		spy(object, "downcase");
		object.downcase();
		expect(object.stubs.downcase.calls).toHaveLength(1);
		expect(object.stubs.downcase.calls[0]).toBeEmpty();
	});
	
	should("return original function's value", function(){
		spy(object, "downcase");
		expect(object.downcase()).toBeEqualTo("some nice string");
	});
	
	should("register messages with arguments", function(){
		spy(object, "substr");
		object.substr(0,4);
		expect(object.stubs.substr.calls).toHaveLength(1);
		expect(object.stubs.substr.calls[0]).toBeEqualTo([0,4]);
	});
	
	should("return stubbed value", function(){
		spy(object, "substr", function(){ return "stubbed"; });
		expect(object.substr(0,4)).toBeEqualTo("stubbed");
	});
	
	should("return stubbed value when multiple spies are set", function(){
		spy(object, "substr", function(){ return "substr"; });
		spy(object, "substring", function(){ return "substring"; });
		
		expect(object.substr(0,4)).toBeEqualTo("substr");
		expect(object.substring(0,4)).toBeEqualTo("substring");
	});
});
